# sketch
A python library for converting Real images to pencil sketch

[![forthebadge made-with-python](http://ForTheBadge.com/images/badges/made-with-python.svg)](https://www.python.org/)                 
[![Python 3.6](https://img.shields.io/badge/python-3.6-blue.svg)](https://www.python.org/downloads/release/python-360/)   

## Usage

- Make sure you have Python and Open-cv installed in your system.
- Run Following command in the CMD.
 ```
  pip install sketchdraw
  ```
## Example

 ```
# test.py

from sketch import sketchit
img_path = 'path/of/image'
sketchit(img_path)
  ```

## Run the following Script.
 ```
  python test.py
 ```
